/* -*-C-*-
 ******************************************************************************
 *
 * File:         open.h
 * RCS:          /usr/local/lib/cvs/open/open.h,v 1.5 1995/05/02 22:18:14 chris Exp
 * Description:  replacement for /usr/bin/open
 * Author:       Christian Limpach <chris@nice.ch>
 * Created:      Wed Mar 20 23:55:53 1994
 * Modified:     Tue May  2 23:20:50 1995 (Christian Limpach) chris@nice.ch
 * Language:     C
 * Package:      open
 * Status:       Released
 *
 * (C) Copyright 1994, Christian Limpach, all rights reserved.
 *
 ******************************************************************************
 */

/*
 * open.h,v
 * Revision 1.5  1995/05/02  22:18:14  chris
 * added -as option to define extensions of files without or with
 * incorrect extensions [suggested by Peter Langston <psl@acm.org>]
 *
 * Revision 1.4  1994/05/30  22:02:54  chris
 * added -help and -version
 *
 * Revision 1.3  1994/05/26  12:47:38  chris
 * added `Foo.client somefile' = `open -a Foo -wait somefile'
 * [suggested by Carl Edman <cedman@princeton.edu>]
 *
 * Revision 1.2  1994/05/09  21:37:39  chris
 * fixed NXHost which was broken because of [Application new]
 *
 * Revision 1.1  1994/05/05  22:32:02  chris
 * replaces /usr/bin/open and adds some nice features
 *
 */

#import <appkit/appkit.h>

#include <sys/param.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <ctype.h>

#define str_copy(str)	((str == NULL) ? NULL : NXCopyStringBuffer(str))
#define str_free(str)	{if (str != NULL) free(str);}

#define WORKSPACE "Workspace"
#define STDINBUFSIZE 1024

#define CLIENTEXT ".client"
#define CLIENTEXTLEN 7

/* openMode modes... */
#define OPEN 1
#define APP 2
#define PRINT 3
#define OPENLINE 4
#define UNHIDE 5

/* fileMode mode... */
#define DISK 1
#define STDIN 2
#define NONE 3
#define TEMP 4

/* help modes */
#define HELP_OPEN 1
#define HELP_APPOPEN 2
#define HELP_UNHIDE 3
#define HELP_OPENAS 4

@interface AppInfo:Object
{
  char *Name;
  char *Host;
  port_t Port;
}

- initFor:(const char *)appName onHost:(const char *)hostName;
- (port_t)port;
- (BOOL)isEntryFor:(const char *)appName:(const char *)hostName;

@end

@interface AppList:List
{
}

- (port_t)getPortFor:(const char *)anApp onHost:(const char *)aHost;

@end
